Module: ForestAdminDatasourceMambuPayments::Client::Writes
- Included in:
- ForestAdminDatasourceMambuPayments::Client
- Defined in:
- lib/forest_admin_datasource_mambu_payments/client/writes.rb
Instance Method Summary collapse
- #approve_payment_order(id, attrs = {}) ⇒ Object
- #cancel_payment_order(id, attrs = {}) ⇒ Object
- #create_account_holder(attrs) ⇒ Object
- #create_direct_debit_mandate(attrs) ⇒ Object
- #create_expected_payment(attrs) ⇒ Object
- #create_external_account(attrs) ⇒ Object
- #create_internal_account(attrs) ⇒ Object
- #create_payment_order(attrs) ⇒ Object
-
#create_reconciliation(attrs) ⇒ Object
Numeral has no DELETE on /reconciliations either; cancel is a lifecycle action and is deferred to a future plugin.
-
#create_return(attrs) ⇒ Object
Numeral has no DELETE on /returns; the lifecycle “cancel”/“approve” are exposed as side-effect actions and would belong in a plugin, not here.
- #delete_account_holder(id) ⇒ Object
- #delete_direct_debit_mandate(id) ⇒ Object
- #delete_expected_payment(id) ⇒ Object
- #delete_external_account(id) ⇒ Object
- #delete_internal_account(id) ⇒ Object
- #delete_payment_order(id) ⇒ Object
- #update_account_holder(id, attrs) ⇒ Object
- #update_direct_debit_mandate(id, attrs) ⇒ Object
- #update_expected_payment(id, attrs) ⇒ Object
- #update_external_account(id, attrs) ⇒ Object
- #update_internal_account(id, attrs) ⇒ Object
- #update_payment_order(id, attrs) ⇒ Object
- #update_reconciliation(id, attrs) ⇒ Object
- #update_return(id, attrs) ⇒ Object
- #verify_external_account(id, attrs = {}) ⇒ Object
Instance Method Details
#approve_payment_order(id, attrs = {}) ⇒ Object
7 |
# File 'lib/forest_admin_datasource_mambu_payments/client/writes.rb', line 7 def approve_payment_order(id, attrs = {}) = post_action_resource('payment_orders', id, 'approve', attrs) |
#cancel_payment_order(id, attrs = {}) ⇒ Object
8 |
# File 'lib/forest_admin_datasource_mambu_payments/client/writes.rb', line 8 def cancel_payment_order(id, attrs = {}) = post_action_resource('payment_orders', id, 'cancel', attrs) |
#create_account_holder(attrs) ⇒ Object
10 |
# File 'lib/forest_admin_datasource_mambu_payments/client/writes.rb', line 10 def create_account_holder(attrs) = post_resource('account_holders', attrs) |
#create_direct_debit_mandate(attrs) ⇒ Object
23 |
# File 'lib/forest_admin_datasource_mambu_payments/client/writes.rb', line 23 def create_direct_debit_mandate(attrs) = post_resource('direct_debit_mandates', attrs) |
#create_expected_payment(attrs) ⇒ Object
27 |
# File 'lib/forest_admin_datasource_mambu_payments/client/writes.rb', line 27 def create_expected_payment(attrs) = post_resource('expected_payments', attrs) |
#create_external_account(attrs) ⇒ Object
14 |
# File 'lib/forest_admin_datasource_mambu_payments/client/writes.rb', line 14 def create_external_account(attrs) = post_resource('external_accounts', attrs) |
#create_internal_account(attrs) ⇒ Object
19 |
# File 'lib/forest_admin_datasource_mambu_payments/client/writes.rb', line 19 def create_internal_account(attrs) = post_resource('internal_accounts', attrs) |
#create_payment_order(attrs) ⇒ Object
4 |
# File 'lib/forest_admin_datasource_mambu_payments/client/writes.rb', line 4 def create_payment_order(attrs) = post_resource('payment_orders', attrs) |
#create_reconciliation(attrs) ⇒ Object
Numeral has no DELETE on /reconciliations either; cancel is a lifecycle action and is deferred to a future plugin.
38 |
# File 'lib/forest_admin_datasource_mambu_payments/client/writes.rb', line 38 def create_reconciliation(attrs) = post_resource('reconciliations', attrs) |
#create_return(attrs) ⇒ Object
Numeral has no DELETE on /returns; the lifecycle “cancel”/“approve” are exposed as side-effect actions and would belong in a plugin, not here.
33 |
# File 'lib/forest_admin_datasource_mambu_payments/client/writes.rb', line 33 def create_return(attrs) = post_resource('returns', attrs) |
#delete_account_holder(id) ⇒ Object
12 |
# File 'lib/forest_admin_datasource_mambu_payments/client/writes.rb', line 12 def delete_account_holder(id) = delete_resource('account_holders', id) |
#delete_direct_debit_mandate(id) ⇒ Object
25 |
# File 'lib/forest_admin_datasource_mambu_payments/client/writes.rb', line 25 def delete_direct_debit_mandate(id) = delete_resource('direct_debit_mandates', id) |
#delete_expected_payment(id) ⇒ Object
29 |
# File 'lib/forest_admin_datasource_mambu_payments/client/writes.rb', line 29 def delete_expected_payment(id) = delete_resource('expected_payments', id) |
#delete_external_account(id) ⇒ Object
16 |
# File 'lib/forest_admin_datasource_mambu_payments/client/writes.rb', line 16 def delete_external_account(id) = delete_resource('external_accounts', id) |
#delete_internal_account(id) ⇒ Object
21 |
# File 'lib/forest_admin_datasource_mambu_payments/client/writes.rb', line 21 def delete_internal_account(id) = delete_resource('internal_accounts', id) |
#delete_payment_order(id) ⇒ Object
6 |
# File 'lib/forest_admin_datasource_mambu_payments/client/writes.rb', line 6 def delete_payment_order(id) = delete_resource('payment_orders', id) |
#update_account_holder(id, attrs) ⇒ Object
11 |
# File 'lib/forest_admin_datasource_mambu_payments/client/writes.rb', line 11 def update_account_holder(id, attrs) = patch_resource('account_holders', id, attrs) |
#update_direct_debit_mandate(id, attrs) ⇒ Object
24 |
# File 'lib/forest_admin_datasource_mambu_payments/client/writes.rb', line 24 def update_direct_debit_mandate(id, attrs) = patch_resource('direct_debit_mandates', id, attrs) |
#update_expected_payment(id, attrs) ⇒ Object
28 |
# File 'lib/forest_admin_datasource_mambu_payments/client/writes.rb', line 28 def update_expected_payment(id, attrs) = patch_resource('expected_payments', id, attrs) |
#update_external_account(id, attrs) ⇒ Object
15 |
# File 'lib/forest_admin_datasource_mambu_payments/client/writes.rb', line 15 def update_external_account(id, attrs) = patch_resource('external_accounts', id, attrs) |
#update_internal_account(id, attrs) ⇒ Object
20 |
# File 'lib/forest_admin_datasource_mambu_payments/client/writes.rb', line 20 def update_internal_account(id, attrs) = patch_resource('internal_accounts', id, attrs) |
#update_payment_order(id, attrs) ⇒ Object
5 |
# File 'lib/forest_admin_datasource_mambu_payments/client/writes.rb', line 5 def update_payment_order(id, attrs) = patch_resource('payment_orders', id, attrs) |
#update_reconciliation(id, attrs) ⇒ Object
39 |
# File 'lib/forest_admin_datasource_mambu_payments/client/writes.rb', line 39 def update_reconciliation(id, attrs) = patch_resource('reconciliations', id, attrs) |
#update_return(id, attrs) ⇒ Object
34 |
# File 'lib/forest_admin_datasource_mambu_payments/client/writes.rb', line 34 def update_return(id, attrs) = patch_resource('returns', id, attrs) |
#verify_external_account(id, attrs = {}) ⇒ Object
17 |
# File 'lib/forest_admin_datasource_mambu_payments/client/writes.rb', line 17 def verify_external_account(id, attrs = {}) = post_action_resource('external_accounts', id, 'verify', attrs) |