Class: ForestAdminDatasourceMambuPayments::Collections::BaseCollection::Embed
- Inherits:
-
Struct
- Object
- Struct
- ForestAdminDatasourceMambuPayments::Collections::BaseCollection::Embed
- Defined in:
- lib/forest_admin_datasource_mambu_payments/collections/base_collection.rb
Overview
A ManyToOne relation to embed: which foreign key on the row, the relation name to populate, and the target collection that resolves and serializes the related records.